@@ -2,7 +2,7 @@
 # -*-coding:utf-8 -*-
 
 """
-# File       : PyGameAutoAndroid.py
+# File       : xiaopy.py
 # Time       ：2022.8.30 23:53
 # Author     ：小派精灵
 # HomePage   : xiaopy.cn
@@ -10,8 +10,6 @@
 # Description：
 """
 
-import time
-
 
 class Point:
     x = None
@@ -24,6 +22,13 @@ class Rect:
     width = None
     height = None
 
+class TextRect:
+    x = None
+    y = None
+    width = None
+    height = None
+    text = None
+    confidence = None
 
 class Text:
     text = None
@@ -48,31 +53,73 @@ class Node:
     selected = None
     rect = Rect
 
+    def parent(self):
+        return Node
+
+    def children(self):
+        return [Node]
+
 
 class Path:
     def __init__(self, x: int, y: int):
         return self
 
-    def moveTo(self, x: int, y: int, duration: float):
+    def moveTo(self, x: int, y: int, duration: float = 0.5):
         return self
 
 
+class UI:
+    def stringValue(self, key: str):
+        pass
+
+    def intValue(self, key: str):
+        pass
+
+    def boolValue(self, key: str):
+        pass
+
+
+class Keyboard:
+    def enter(self):
+        pass
+
+    def inputText(self, text: str):
+        pass
+
+    def inputTextAndEnter(self, text: str):
+        pass
+
+    def clearText(self):
+        pass
+
+
 class Size:
     width = None
     height = None
 
-
-def IdSelector(id: str):
-    pass
+class Selector:
+    def join(self, selector):
+        pass
 
 
-def TextSelector(text: str):
-    pass
+class IdSelector(Selector):
+    def __init__(self, id: str):
+        pass
 
 
-def DescSelector(desc: str):
-    pass
 
+class TextSelector(Selector):
+    def __init__(self, text: str):
+        pass
+
+
+class DescSelector(Selector):
+    def __init__(self, desc: str):
+        pass
+
+class ClassSelector(Selector):
+    def __init__(self, cls: str):
+        pass
 
 class xp:
     @classmethod
@@ -104,7 +151,17 @@ class xp:
         pass
 
     @classmethod
-    def matchColor(cls, colorDesc: str, x: int = 0, y: int = 0):
+    def getColor(cls, x: int, y: int):
+        """
+        获取颜色
+        :param x: x 坐标
+        :param y: y 坐标
+        :return:
+        """
+        pass
+
+    @classmethod
+    def matchColor(cls, colorDesc: str, x: int, y: int, sim: float):
         """
         匹配颜色
         :param colorDesc: 颜色描述
@@ -168,7 +225,7 @@ class xp:
         :param sim: 相似度
         :return:
         """
-        return Rect
+        return TextRect
 
     @classmethod
     def findTextAll(cls, text: str, x1: int = 0, y1: int = 0, x2: int = 0, y2: int = 0, sim: float = 0.9):
@@ -182,7 +239,7 @@ class xp:
         :param sim:
         :return:
         """
-        return [Rect]
+        return [TextRect]
 
     @classmethod
     def getText(cls, x1: int = 0, y1: int = 0, x2: int = 0, y2: int = 0):
@@ -194,7 +251,7 @@ class xp:
         :param y2: 终点 y 坐标
         :return:
         """
-        return Text
+        return TextRect
 
     @classmethod
     def getTextAll(cls, x1: int = 0, y1: int = 0, x2: int = 0, y2: int = 0):
@@ -206,7 +263,7 @@ class xp:
         :param y2:
         :return:
         """
-        return [Text]
+        return [TextRect]
 
     @classmethod
     def findNode(cls, selector):
@@ -296,6 +353,15 @@ class xp:
         """
         pass
 
+    @classmethod
+    def closeApp(cls, packageName: str):
+        """
+        关闭APP
+        :param packageName:
+        :return:
+        """
+        pass
+
     @classmethod
     def currentAppPackageName(cls):
         """
@@ -312,6 +378,15 @@ class xp:
         """
         return Size
 
+    @classmethod
+    def screenshot(cls, fileName: str=None, x1: int = 0, y1: int = 0, x2: int = 0, y2: int = 0):
+        """
+        截图
+        :param fileName: 文件名
+        :return:
+        """
+        pass
+
     @classmethod
     def inputText(cls, text: str):
         """
@@ -328,3 +403,19 @@ class xp:
         :return:
         """
         pass
+
+    @classmethod
+    def ui(cls):
+        """
+        获取UI对象
+        :return:
+        """
+        return UI()
+
+    @classmethod
+    def keyboard(cls):
+        """
+        获取键盘对象
+        :return:
+        """
+        return Keyboard()
